==> jboss-osgi-spi-1.0.2-sources.jar: org/jboss/osgi/spi/capability/ConfigAdminCapability.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.osgi.spi.capability;

//$Id: ConfigAdminCapability.java 93517 2009-09-15 09:36:31Z thomas.diesler@jboss.com $

import org.jboss.osgi.spi.testing.OSGiRuntime;
import org.osgi.service.cm.ConfigurationAdmin;

/**
 * Adds the OSGi compedium ConfigAdmin capability to the {@link OSGiRuntime}
 * under test. 
 * 
 * It is ignored if the {@link ConfigurationAdmin} is already registered.
 * 
 * Installed bundles: org.apache.felix.metatype.jar, org.apache.felix.configadmin.jar
 * 
 * @author thomas.diesler@jboss.com
 * @since 05-May-2009
 */
public class ConfigAdminCapability extends Capability
{
   public ConfigAdminCapability()
   {
      super(ConfigurationAdmin.class.getName());
      
      addDependency(new CompendiumCapability());
      
      addBundle("bundles/org.apache.felix.metatype.jar");
      addBundle("bundles/org.apache.felix.configadmin.jar");
   }
}

==> jboss-osgi-spi-1.0.5-sources.jar: org/jboss/osgi/spi/capability/ConfigAdminCapability.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.osgi.spi.capability;

//$Id: ConfigAdminCapability.java 101072 2010-02-17 13:55:15Z thomas.diesler@jboss.com $

import org.osgi.service.cm.ConfigurationAdmin;

/**
 * Adds the OSGi compedium ConfigAdmin capability to the OSGiRuntime
 * under test. 
 * 
 * It is ignored if the {@link ConfigurationAdmin} is already registered.
 * 
 * Installed bundles: org.apache.felix.metatype.jar, org.apache.felix.configadmin.jar
 * 
 * @author thomas.diesler@jboss.com
 * @since 05-May-2009
 */
public class ConfigAdminCapability extends Capability
{
   public ConfigAdminCapability()
   {
      super(ConfigurationAdmin.class.getName());
      
      addDependency(new CompendiumCapability());
      
      addBundle("bundles/org.apache.felix.metatype.jar");
      addBundle("bundles/org.apache.felix.configadmin.jar");
   }
}
